import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:on_time_app/home/default_app_tab.dart';
import 'package:on_time_app/tabs/check_in_tab.dart';
import 'package:on_time_app/tabs/check_in_wifi_tab.dart';
import 'package:on_time_app/tabs/holiday_tab.dart';
import 'package:on_time_app/tabs/settings_tab.dart';
import 'package:on_time_app/utils/config.dart';

@protected
class AndroidHomeMenu extends StatelessWidget {
  final String userMail;

  AndroidHomeMenu(this.userMail);

  Widget _androidDrawer(BuildContext context, GlobalKey mainKey) {
    return SizedBox(
        width: MediaQuery.of(context).size.width * 0.75,
        child: Drawer(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Padding(
                padding: EdgeInsets.all(15),
                  child: Image(
                      image: AssetImage('images/header.png'),
                      width: 200,
                      height: 160)),
              ListTile(
                leading: DefaultAppTab.androidIcon,
                title: Text(DefaultAppTab.title),
                onTap: () {
                  Navigator.pop(context);
                },
              ),
              ListTile(
                leading: CheckInWifiTab.androidIcon,
                title: Text(CheckInWifiTab.title),
                onTap: () async {
                  Navigator.pop(context);
                  Navigator.of(context).push(MaterialPageRoute(
                      builder: (context) => Config.useWifi
                          ? CheckInWifiTab(userMail)
                          : CheckInTab(userMail)));
                },
              ),
              ListTile(
                leading: HolidayTab.androidIcon,
                title: Text(HolidayTab.title),
                onTap: () {
                  Navigator.pop(context);
                  Navigator.push<void>(
                      context,
                      MaterialPageRoute(
                          builder: (context) => HolidayTab(userMail)));
                },
              ),
              // Long drawer contents are often segmented.
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16),
                child: Divider(),
              ),
              ListTile(
                leading: SettingsTab.androidIcon,
                title: Text(SettingsTab.title),
                onTap: () {
                  Navigator.pop(context);
                  Navigator.push<void>(context,
                      MaterialPageRoute(builder: (context) => SettingsTab()));
                },
              ),
            ],
          ),
        ));
  }

  @override
  Widget build(BuildContext context) {
    final _key = GlobalKey();
    return DefaultAppTab(
      userMail,
      androidDrawer: _androidDrawer(context, _key),
      key: _key,
    );
  }
}
